@@ -14,8 +14,9 @@ class ProcessorMixin(object):
             try:
                 fn = self._processMap[name]
             except KeyError:
-                raise TApplicationException(TApplicationException.UNKNOWN_METHOD,
-                                            'Unknown function %s' % (name))
+                msg = 'Unknown function %s' % (name)
+                code = TApplicationException.UNKNOWN_METHOD
+                raise TApplicationException(code, msg)
             else:
                 fn(self, seqid, iprot, oprot)
 
